analytical.grad: Analytical gradient of the log-likelihood function of the (E)CCC-GARCH(1,1) model
Description
This function returns the analytical gradient of the log-likelihood function of the (E)CCC-GARCH(1,1) model.Usage
analytical.grad(a, A, B, R, u, model)
Arguments
a
a vector of constants in the vector GARCH equation $(N \times 1)$
A
an ARCH parameter matrix in the vector GARCH equation $(N \times N)$
B
a GARCH parameter matrix in the vector GARCH equation $(N \times N)$
R
a constant conditional correlation matrix $(N \times N)$
u
a matrix of the observed residuals $(T \times N)$
model
a character string describing the model. "diagonal" for the diagonal model
and "extended" for the extended (full ARCH and GARCH parameter matrices) model
Value
- a $npar \times T$ matrix of gradients
References
Nakatani, T. and T. Ter"asvirta (2009),
Testing for Volatility Interactions in the Constant Conditional Correlation GARCH Model,
Econometrics Journal, 12, 147--163.
Nakatani, T. and T. Ter"asvirta (2008),
Appendix to Testing for Volatility Interactions in the Constant Conditional Correlation GARCH Model
Department of Economic Statistics, Stockholm School of Economics,
available at http://swopec.hhs.se/hastef/abs/hastef0649.htm.