Learn R Programming

ccgarch (version 0.1.4-2)

loglik.dcc: The log-likelihood function for the (E)DCC GARCH model

Description

This function returns a log-likelihood of the (E)DCC-GARCH model.

Usage

loglik.dcc(param, dvar, model)

Arguments

param
a vector of all the parameters in the (E)DCC-GARCH model.
dvar
a matrix of the observed residuals $(T \times N)$
model
a character string describing the model. "diagonal" for the diagonal model and "extended" for the extended (full ARCH and GARCH parameter matrices) model

Value

  • the negative of the full log-likelihood of the (E)DCC-GARCH model

References

Robert F. Engle and Kevin Sheppard (2001), Theoretical and Empirical Properties of Dynamic Conditional Correlation Multivariate GARCH. {Stern Finance Working Paper Series} FIN-01-027 (Revised in Dec. 2001), New York University Stern School of Business. Robert F. Engle (2002), Dynamic Conditional Correlation: A Simple Class of Multivariate Generalised Autoregressive Conditional Heteroskedasticity Models. Journal of Business and Economic Statistics 20, 339--350. # Simulating data from the original DCC-GARCH(1,1) process nobs <- 1000; cut <- 1000 a <- c(0.003, 0.005, 0.001) A <- diag(c(0.2,0.3,0.15)) B <- diag(c(0.75, 0.6, 0.8)) uncR <- matrix(c(1.0, 0.4, 0.3, 0.4, 1.0, 0.12, 0.3, 0.12, 1.0),3,3) dcc.para <- c(0.01,0.98) dcc.data <- dcc.sim(nobs, a, A, B, uncR, dcc.para, model="diagonal") # Estimating a DCC-GARCH(1,1) model dcc.results <- dcc.estimation(inia=a, iniA=A, iniB=B, ini.dcc=dcc.para, dvar=dcc.data$eps, model="diagonal") # Parameter estimates and their robust standard errors dcc.results$out # Computing the value of the log-likelihood at the estimates loglik.dcc(dcc.results$out[1,], dcc.data$eps, model="diagonal") ts, models, multivariate