Learn R Programming

ccgarch (version 0.2.2)

loglik.dcc1: The 1st stage log-likelihood function for the (E)DCC GARCH

Description

This function returns a log-likelihood of the (E)DCC-GARCH model in the first stage estimation.

Usage

loglik.dcc1(param, dvar, model)

Arguments

param
initial values for a vector of the parameters $(npar \times 1)$
dvar
a matrix of the data $(T \times N)$
model
a character string describing the model. "diagonal" for the diagonal model and "extended" for the extended (full ARCH and GARCH parameter matrices) model

Value

  • the negative of the first stage log-likelihood

References

Engle, R.F. and K. Sheppard (2001), Theoretical and Empirical Properties of Dynamic Conditional Correlation Multivariate GARCH. Stern Finance Working Paper Series FIN-01-027 (Revised in Dec. 2001), New York University Stern School of Business. Engle, R.F. (2002), Dynamic Conditional Correlation: A Simple Class of Multivariate Generalized Autoregressive Conditional Heteroskedasticity Models. Journal of Business and Economic Statistics 20, 339--350.

See Also

dcc.estimation, dcc.estimation1