Learn R Programming

ccgarch (version 0.2.2)

uni.vola.sim: Simulating a series with univariate GARCH(1,1) conditional variances

Description

This function simulates an univariate time series with GARCH(1,1) conditional variances.

Usage

uni.vola.sim(a, nobs, d.f=Inf, cut=1000)

Arguments

a
a vector of parameters $(3 \times 1)$
nobs
a number of observations simulated $(T)$
d.f
degrees of freedom parameter for $t$-distribution
cut
a number of observations to be removed to minimise the initial effects

Value

  • A list with components:
  • hGARCH(1,1) conditional variances $(T \times 1)$
  • epsa series of error term with the conditional variances "h" $(T \times 1)$

References

Bollerslev, T. (1986), Generalized Autoregressive Conditional Heteroskedasticity, Journal of Econometrics, 31, 307--327. Fiorentini, G., G. Calzolari and L. Panattoni (1996), Analytic Derivatives and the Computation of GARCH Estimates, Journal of Applied Econometrics, 11, 399--417.

See Also

uni.vola

Examples

Run this code
nobs <- 1000
nu <- 8
a <- c(0.1,0.2,0.7)           #  a <- c(a constant, ARCH parameter, GARCH parameter) 
# with normal innovations
eps <- uni.vola.sim(a, nobs)
# with t innovations
eps.t <- uni.vola.sim(a, nobs, d.f = df)

Run the code above in your browser using DataLab