Learn R Programming

ccgarch (version 0.1.2-2)

loglik.dcc: The log-likelihood function for the (E)DCC GARCH model

Description

This function returns a log-likelihood of the (E)DCC-GARCH model.

Usage

loglik.dcc(param, dvar, model)

Arguments

param
a vector of all the parameters in the (E)DCC-GARCH model.
dvar
a matrix of the observed residuals $(T \times N)$
model
a character string describing the model. "diagonal" for the diagonal model and "extended" for the extended (full ARCH and GARCH parameter matrices) model

Value

  • the negative of the full log-likelihood of the (E)DCC-GARCH model

References

Engle, R.F. and K. Sheppard (2001), Theoretical and Empirical Properties of Dynamic Conditional Correlation Multivariate GARCH. Stern Finance Working Paper Series FIN-01-027 (Revised in Dec. 2001), New York University Stern School of Business. Engle, R.F. (2002), Dynamic Conditional Correlation: A Simple Class of Multivariate Generalised Autoregressive Conditional Heteroskedasticity Models. Journal of Business and Economic Statistics 20, 339--350.