Learn R Programming

ccgarch (version 0.2.2)

stationarity: The stationarity condition in Extended CC-GARCH models

Description

A utility function that checks if the two parameter matrices in a vector GARCH model satisfy the stationarity condition.

Usage

stationarity(A,B)

Arguments

A
an ARCH parameter matrix in the vector GARCH equation $(N \times N)$
B
a GARCH parameter matrix in the vector GARCH equation $(N \times N)$

Value

  • a scalar. If strictly less than unity, the condition is satisfied.

References

He, C. and T. Ter"asvirta (2004): An Extende Constant Conditional Correlation GARCH model and its Fourth-moment Structure, Econometric Theory, 20, 904--926. Nakatani, T. and T. Ter"asvirta (2009), Testing for Volatility Interactions in the Constant Conditional Correlation GARCH Model, Econometrics Journal, 12, 147--163. Nakatani, T. and T. Ter"asvirta (2008), Appendix to Testing for Volatility Interactions in the Constant Conditional Correlation GARCH Model Department of Economic Statistics, Stockholm School of Economics, available at http://swopec.hhs.se/hastef/abs/hastef0649.htm.

See Also

fourth